@@ -492,6 +492,8 @@ def replace_with_correct_data(trial_dir_input, gaze_dir_input, gaze_start_end_in
     gaze_start_index = gaze_start_end_input["start_index"]
     gaze_end_index = gaze_start_end_input["end_index"]
 
+    # get is_event, event_id and direction value from the input csv
+    # because gaze.csv does not have these values
     with open(trial_dir_input, "r") as trial_csv_file:
         trial_csv_data = csv.reader(trial_csv_file, delimiter=',')
         trial_header_array = next(trial_csv_data)
@@ -506,11 +508,13 @@ def replace_with_correct_data(trial_dir_input, gaze_dir_input, gaze_start_end_in
         direction_value = trial_rows[0][direction_position]
         trial_csv_file.close()
 
+    # get the trial data from gaze.csv by using start index and end index
     with open(gaze_dir_input, "r") as gaze_csv_file:
         gaze_csv_data = csv.reader(gaze_csv_file, delimiter=',')
         header_array = next(gaze_csv_data)
 
         # sts = sensor timestamp, g = gaze, rts = record timestamp
+        # get the header positions which rows need to be modified and used
         g_is_event_position = get_position("is_event", header_array)
         g_event_string_position = get_position("event_string", header_array)
         g_sts_position = get_position("sensor_timestamp", header_array)
@@ -527,11 +531,13 @@ def replace_with_correct_data(trial_dir_input, gaze_dir_input, gaze_start_end_in
         got_first_sts = False
         for data in correct_data_array:
             output_data = data
+            # record first sensor timestamp to be used to calculate record timestamp
             if not got_first_sts:
                 first_sts = float(data[g_sts_position])
                 got_first_sts = True
             record_ts = float(data[g_sts_position]) - first_sts
             # noinspection PyTypeChecker
+            # modify and add columns from gaze data to trial data
             output_data[g_rts_position] = record_ts
             output_data[g_is_event_position] = is_event_value
             output_data[g_event_string_position] = event_id_value
@@ -540,6 +546,7 @@ def replace_with_correct_data(trial_dir_input, gaze_dir_input, gaze_start_end_in
 
         gaze_csv_file.close()
 
+    # rewrite and replace incorrect data with correct data
     with open(trial_dir_input, mode='w', newline="") as new_destination_file:
         csv_writer = csv.DictWriter(new_destination_file, fieldnames=trial_header_array)
         csv_writer.writeheader()
@@ -585,7 +592,7 @@ def get_config_location(package_name, config_file_name):
 def main():
     parser = argparse.ArgumentParser(prog='oknpatch',
                                      description='OKNPATCH package.')
-    parser.add_argument('--version', action='version', version='1.0.1'),
+    parser.add_argument('--version', action='version', version='1.0.2'),
     parser.add_argument("-t", dest="type_input", required=True, default=sys.stdin,
                         help="issue type to fix", metavar="issue type")
     parser.add_argument("-i", dest="first_input", required=False, default=sys.stdin,
@@ -602,17 +609,22 @@ def main():
     third_input = args.third_input
 
     if str(type_input) == "trial_data_lost":
+        # If first input and second input are provided or not "None"
         if "io.TextIOWrapper" not in str(first_input) and "io.TextIOWrapper" not in str(second_input):
-            # check whether any of those files is missing or not
+            # Check whether any of those files is missing or not and the file name is correct or not
             file_name_array = [["trial", first_input], ["gaze", second_input]]
             dir_exist_array = get_file_dir_exist_array(file_name_array)
             all_file_found = True
+
+            # Display if any of file is missing
             for exist_array in dir_exist_array:
                 if not exist_array[1]:
                     print("")
                     print(f"Error! {exist_array[2]} file is missing in {exist_array[0]}.")
                     print("")
                     all_file_found = False
+
+            # No file is missing
             if all_file_found:
                 print("")
                 print("All necessary csv files are found.")
@@ -636,19 +648,23 @@ def main():
                 print(f"Second input is missing to fix {type_input} issue.")
                 print("")
     elif str(type_input) == "update":
+        # If first input is provided or not "None"
         if "io.TextIOWrapper" not in str(first_input):
-            # check whether input file exists or not
+            # Check whether input file exists or not
             file_exist = os.path.isfile(first_input)
             if file_exist:
                 print("")
                 print("Input file is found.")
                 print("")
+                # Determine whether default extra_string or custom input needs to be used
                 if "io.TextIOWrapper" not in str(second_input):
                     extra_string = str(second_input)
                 else:
                     print("There is no extra string input to name updated_csv.")
                     extra_string = "updated_"
                     print(f"Therefore using default extra string:{extra_string}")
+
+                # Determine whether build-in config or input config needs to be used
                 if "io.TextIOWrapper" not in str(third_input):
                     config_dir_exist = os.path.isfile(third_input)
                     if config_dir_exist:
@@ -668,10 +684,11 @@ def main():
                     print(f"{output_file} is created in {output_file_location}")
                 else:
                     print(error)
+            else:
+                print(f"Input file:{first_input} does not exist.")
         else:
-            if "io.TextIOWrapper" in str(first_input):
-                print("")
-                print(f"First input is missing to fix {type_input} issue.")
-                print("")
+            print("")
+            print(f"First input is missing to fix {type_input} issue.")
+            print("")
     else:
         print(f"Invalid issue type: {type_input}")
